Installation — GuessIt 0.8.dev0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- GuessIt 0.8.dev0 documentation »

# Installation

This part of the documentation covers the installation of GuessIt. The first step to using any software package is getting it properly installed.

## Distribute & Pip

Installing GuessIt is simple with pip:

    $ pip install guessit

or, with easy_install:

    $ easy_install guessit

But, you really shouldn’t do that.

## Get the Code

GuessIt is actively developed on GitHub, where the code is always available.

You can either clone the public repository:

    git clone git://github.com/wackou/guessit.git

Download the tarball:

    $ curl -L https://github.com/wackou/guessit/tarball/master -o guessit.tar.gz

Or, download the zipball:

    $ curl -L https://github.com/wackou/guessit/zipball/master -o guessit.zip

Once you have a copy of the source, you can embed it in your Python package, or install it into your site-packages easily:

    $ python setup.py install